export async function onRequestPost(context: RequestContext) {
  const { permissions } = context.data.current_user;

  if (!(permissions & (1 << 0)) || !(permissions & (1 << 11)))
    return new Response('{"error":"Forbidden"}', {
      headers: {
        "content-type": "application/json",
      },
      status: 403,
    });

  const { body } = context.data;
  const id = context.params.id as string;

  if (id.search(/^\d{16,19}$/) === -1)
    return new Response('{"error":"Invalid target id"}', {
      headers: {
        "content-type": "application/json",
      },
      status: 400,
    });

  context.data.targetId = id;

  if (
    body.feedback &&
    (typeof body.feedback !== "string" || body.feedback.length > 512)
  )
    return new Response('{"error":"Invalid feedback"}', {
      headers: {
        "content-type": "application/json",
      },
      status: 400,
    });

  return await context.next();
}
